"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FieldMessage = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_unistyles_1 = require("react-native-unistyles");
const enums_1 = require("@procyon/types/enums");
const FieldMessage = ({ style, message, status, size, }) => {
    const { styles } = (0, react_native_unistyles_1.useStyles)(styleSheet, { status, size });
    if (!message) {
        return null;
    }
    else {
        return react_1.default.createElement(react_native_1.Text, { style: [styles.procyon_field_message(), style] }, message);
    }
};
exports.FieldMessage = FieldMessage;
const styleSheet = (0, react_native_unistyles_1.createStyleSheet)((theme) => ({
    procyon_field_message: () => {
        const variantForStatus = (status) => ({
            color: status === enums_1.StatusEnum.none
                ? theme.components.field.input.color
                : theme.components.field[status].border,
        });
        const variantForSize = (size) => ({
            fontSize: theme.fontSize[size] - 2,
        });
        return {
            padding: theme.spacing.md,
            paddingTop: 2,
            fontFamily: theme.fontFamily,
            variants: {
                status: {
                    [enums_1.StatusEnum.none]: variantForStatus(enums_1.StatusEnum.none),
                    [enums_1.StatusEnum.info]: variantForStatus(enums_1.StatusEnum.info),
                    [enums_1.StatusEnum.success]: variantForStatus(enums_1.StatusEnum.success),
                    [enums_1.StatusEnum.warning]: variantForStatus(enums_1.StatusEnum.warning),
                    [enums_1.StatusEnum.error]: variantForStatus(enums_1.StatusEnum.error),
                },
                size: {
                    [enums_1.SizeEnum.sm]: variantForSize(enums_1.SizeEnum.sm),
                    [enums_1.SizeEnum.md]: variantForSize(enums_1.SizeEnum.md),
                    [enums_1.SizeEnum.lg]: variantForSize(enums_1.SizeEnum.lg),
                    [enums_1.SizeEnum.xl]: variantForSize(enums_1.SizeEnum.xl),
                },
            },
        };
    },
}));
